==> inference_gpu-0.24.0-py3-none-any.whl: inference/core/workflows/execution_engine/constants.py <==
NODE_COMPILATION_OUTPUT_PROPERTY = "node_compilation_output"
STEP_DEFINITION_PROPERTY = "definition"
WORKFLOW_INPUT_BATCH_LINEAGE_ID = "<workflow_input>"
IMAGE_TYPE_KEY = "type"
IMAGE_VALUE_KEY = "value"
ROOT_PARENT_ID_KEY = "root_parent_id"
PARENT_ID_KEY = "parent_id"
KEYPOINTS_KEY_IN_INFERENCE_RESPONSE = "keypoints"
KEYPOINTS_CLASS_NAME_KEY_IN_INFERENCE_RESPONSE = "class_name"
KEYPOINTS_CLASS_ID_KEY_IN_INFERENCE_RESPONSE = "class_id"
KEYPOINTS_CONFIDENCE_KEY_IN_INFERENCE_RESPONSE = "confidence"
KEYPOINTS_CLASS_ID_KEY_IN_SV_DETECTIONS = "keypoints_class_id"
KEYPOINTS_CLASS_NAME_KEY_IN_SV_DETECTIONS = "keypoints_class_name"
KEYPOINTS_CONFIDENCE_KEY_IN_SV_DETECTIONS = "keypoints_confidence"
KEYPOINTS_XY_KEY_IN_SV_DETECTIONS = "keypoints_xy"
IMAGE_DIMENSIONS_KEY = "image_dimensions"
PREDICTION_TYPE_KEY = "prediction_type"
PARENT_COORDINATES_KEY = "parent_coordinates"
PARENT_DIMENSIONS_KEY = "parent_dimensions"
BOUNDING_RECT_RECT_KEY_IN_SV_DETECTIONS = "rect"
BOUNDING_RECT_WIDTH_KEY_IN_SV_DETECTIONS = "width"
BOUNDING_RECT_HEIGHT_KEY_IN_SV_DETECTIONS = "height"
BOUNDING_RECT_ANGLE_KEY_IN_SV_DETECTIONS = "angle"
BOUNDING_RECT_RECT_KEY_IN_INFERENCE_RESPONSE = "rect"
BOUNDING_RECT_WIDTH_KEY_IN_INFERENCE_RESPONSE = "width"
BOUNDING_RECT_HEIGHT_KEY_IN_INFERENCE_RESPONSE = "height"
BOUNDING_RECT_ANGLE_KEY_IN_INFERENCE_RESPONSE = "angle"
PATH_DEVIATION_KEY_IN_SV_DETECTIONS = "path_deviation"
PATH_DEVIATION_KEY_IN_INFERENCE_RESPONSE = "path_deviation"
TIME_IN_ZONE_KEY_IN_SV_DETECTIONS = "time_in_zone"
TIME_IN_ZONE_KEY_IN_INFERENCE_RESPONSE = "time_in_zone"
SCALING_RELATIVE_TO_PARENT_KEY = "scaling_relative_to_parent"
ROOT_PARENT_COORDINATES_KEY = "root_parent_coordinates"
ROOT_PARENT_DIMENSIONS_KEY = "root_parent_dimensions"
SCALING_RELATIVE_TO_ROOT_PARENT_KEY = "scaling_relative_to_root_parent"
DETECTED_CODE_KEY = "data"
WIDTH_KEY = "width"
HEIGHT_KEY = "height"
DETECTION_ID_KEY = "detection_id"
X_KEY = "x"
Y_KEY = "y"
CONFIDENCE_KEY = "confidence"
CLASS_ID_KEY = "class_id"
CLASS_NAME_KEY = "class"
POLYGON_KEY = "points"
TRACKER_ID_KEY = "tracker_id"
INFERENCE_ID_KEY = "inference_id"

==> inference_gpu-0.35.0-py3-none-any.whl: inference/core/workflows/execution_engine/constants.py <==
NODE_COMPILATION_OUTPUT_PROPERTY = "node_compilation_output"
PARSED_NODE_INPUT_SELECTORS_PROPERTY = "parsed_node_input_selectors"
STEP_DEFINITION_PROPERTY = "definition"
WORKFLOW_INPUT_BATCH_LINEAGE_ID = "<workflow_input>"
IMAGE_TYPE_KEY = "type"
IMAGE_VALUE_KEY = "value"
ROOT_PARENT_ID_KEY = "root_parent_id"
PARENT_ID_KEY = "parent_id"
KEYPOINTS_KEY_IN_INFERENCE_RESPONSE = "keypoints"
KEYPOINTS_CLASS_NAME_KEY_IN_INFERENCE_RESPONSE = "class"
KEYPOINTS_CLASS_ID_KEY_IN_INFERENCE_RESPONSE = "class_id"
KEYPOINTS_CONFIDENCE_KEY_IN_INFERENCE_RESPONSE = "confidence"
KEYPOINTS_CLASS_ID_KEY_IN_SV_DETECTIONS = "keypoints_class_id"
KEYPOINTS_CLASS_NAME_KEY_IN_SV_DETECTIONS = "keypoints_class_name"
KEYPOINTS_CONFIDENCE_KEY_IN_SV_DETECTIONS = "keypoints_confidence"
KEYPOINTS_XY_KEY_IN_SV_DETECTIONS = "keypoints_xy"
IMAGE_DIMENSIONS_KEY = "image_dimensions"
PREDICTION_TYPE_KEY = "prediction_type"
PARENT_COORDINATES_KEY = "parent_coordinates"
PARENT_DIMENSIONS_KEY = "parent_dimensions"
BOUNDING_RECT_RECT_KEY_IN_SV_DETECTIONS = "rect"
BOUNDING_RECT_WIDTH_KEY_IN_SV_DETECTIONS = "width"
BOUNDING_RECT_HEIGHT_KEY_IN_SV_DETECTIONS = "height"
BOUNDING_RECT_ANGLE_KEY_IN_SV_DETECTIONS = "angle"
BOUNDING_RECT_RECT_KEY_IN_INFERENCE_RESPONSE = "rect"
BOUNDING_RECT_WIDTH_KEY_IN_INFERENCE_RESPONSE = "width"
BOUNDING_RECT_HEIGHT_KEY_IN_INFERENCE_RESPONSE = "height"
BOUNDING_RECT_ANGLE_KEY_IN_INFERENCE_RESPONSE = "angle"
PATH_DEVIATION_KEY_IN_SV_DETECTIONS = "path_deviation"
PATH_DEVIATION_KEY_IN_INFERENCE_RESPONSE = "path_deviation"
TIME_IN_ZONE_KEY_IN_SV_DETECTIONS = "time_in_zone"
TIME_IN_ZONE_KEY_IN_INFERENCE_RESPONSE = "time_in_zone"
SCALING_RELATIVE_TO_PARENT_KEY = "scaling_relative_to_parent"
ROOT_PARENT_COORDINATES_KEY = "root_parent_coordinates"
ROOT_PARENT_DIMENSIONS_KEY = "root_parent_dimensions"
SCALING_RELATIVE_TO_ROOT_PARENT_KEY = "scaling_relative_to_root_parent"
DETECTED_CODE_KEY = "data"
WIDTH_KEY = "width"
HEIGHT_KEY = "height"
DETECTION_ID_KEY = "detection_id"
X_KEY = "x"
Y_KEY = "y"
CONFIDENCE_KEY = "confidence"
CLASS_ID_KEY = "class_id"
CLASS_NAME_KEY = "class"
POLYGON_KEY = "points"
TRACKER_ID_KEY = "tracker_id"
INFERENCE_ID_KEY = "inference_id"
